<?php
namespace Teknisa\SM\Controller;

use Teknisa\SM\Controller\SMCrud;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\SM\Service\Sm00035000MaximoCarenciaPropostaPerfilAcessoService;

class Sm00035000MaximoCarenciaPropostaPerfilAcessoController extends SMCrud
{
    protected $dataSourceName = 'fct_carenciaperfil_perfilacesso';
    protected $ServiceCarenciaPerfProp;
    
    public function __construct ($crudService, $environment, Sm00035000MaximoCarenciaPropostaPerfilAcessoService $ServiceCarenciaPerfProp) {
        parent::__construct($crudService, $environment);
        $this->serviceCarenciaPerfProp = $ServiceCarenciaPerfProp;
    }
    
    
    public function save(Request $request, Response $response) {
        $request->setParameter('dbname', $this->dataSourceName);
        parent::save($request, $response);
	    $response->addDataSet(new DataSet('columnsToReturn', $this->crudService->getColumnsToReturn()));
    }
    
    public function saveFaixaDesc(Request $request, Response $response) {
        try{
            $row = $request->getRow();
            $numeroPerfil   =   isset($row["NRPERFILACESSO"]) ? $row["NRPERFILACESSO"] : null;
            $numeroOperador =   isset($row["NRCARENCIAOPER"]) ? $row["NRCARENCIAOPER"] : null;
            $valorPercAte   =   $row["VRPERCDESCATE"];
            $valorPercDe    =   $row["VRPERCDESCDE"];
            $numeroCarencia =   $row["NRCARENCIAFAIXA"];
            $numerParcMax   =   $row["NRPARCELASMAX"];
            $inserir        =   $row["INSERIR"];
            if($inserir)
                $inserido = $this->serviceCarenciaPerfProp->insereFaixaDesconto($numeroPerfil, $numeroOperador, $valorPercDe, $valorPercAte, $numeroCarencia, $numerParcMax);
            else{
                $nrCarencia = $row["NRCARENCIAFAIXADESC"];
                $inserido = $this->serviceCarenciaPerfProp->atualizaFaixaDesconto($numeroPerfil, $numeroOperador, $valorPercDe, $valorPercAte, $numeroCarencia, $numerParcMax, $nrCarencia);
            }
            $dataSetResposta = new DataSet('request', array('resulted' => $inserido));
            $response->addDataSet($dataSetResposta);
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * A função "validaCarenciaOperador" verifica se já existe 
     * uma carencia cadastrada para o operador indicado.
     */
    
    public function validaCarenciaPerfilAcesso(Request\Row $request, Response $response) {
    
        $row = $request->getRow();
        
        $perfAcesso = $row['NRPERFILACESSO']; 
        
        $validaCarenciaPerfOper = $this->serviceCarenciaPerfProp->validaCarenciaPerfilAcesso($perfAcesso);
        
        $dtsValCarenciaPerf = new DataSet('VALIDAPERF', array('VALIDA'=>$validaCarenciaPerfOper));
        
        $response->addDataSet($dtsValCarenciaPerf);
    
    }
    
    public function find(Request\Filter $request, Response $response) {
    
        $request->setParameter('dbname', $this->dataSourceName);
        parent::find($request, $response);
    
    }
    
    public function delete(Request $request, Response $response) {
    
        $request->setParameter('dbname', $this->dataSourceName);
        parent::delete($request, $response);
    
    }
    
    public function pegarBetweenCarencia(Request $request, Response $response) {
        try{
            $row = $request->getRow();
            $vrini   =   $row["VRINI"];
            $vrfin    =   $row["VRFIN"];
            $nrOperador        =   isset($row["NRCARENCIAOPER"]) ? ($row["NRCARENCIAOPER"]) : ($row["NRPERFILACESSO"]);
            if(isset($row["NRCARENCIAOPER"])){
                $inserido = $this->serviceCarenciaPerfProp->pegarBetweenCarenciaOperador($vrini, $vrfin, $nrOperador);
            }else{
                $inserido = $this->serviceCarenciaPerfProp->pegarBetweenCarenciaPerfil($vrini, $vrfin, $nrOperador);
            }
            $dataSetResposta = new DataSet('request', array('resulted' => $inserido));
            $response->addDataSet($dataSetResposta);
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
}
?>