<?php

namespace Teknisa\SM\Controller;

use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\SM\Service\SmAssinaturaDigitalService;
use Zeedhi\Framework\DTO\Row;
use Zeedhi\Framework\HTTP\Kernel;

class SmAssinaturaDigitalController {

    protected $smAsssinaDigitalservice;
    protected $httpKernel;

    public function __construct(SmAssinaturaDigitalService $smAsssinaDigitalservice, Kernel $httpKernel){
        $this->smAssinaDigitalservice = $smAsssinaDigitalservice;
        $this->httpKernel = $httpKernel;
    }

    public function uploadtoCertsing(Request $request, Response $response){
        try {

             $upload = $this->smAssinaDigitalservice->uploadtoCertsing();

             $response->addDataSet(new DataSet("RESULT", $upload));

        } catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }


    public function createSignatureCertsing(Request $request, Response $response){
        try {

            $create = $this->smAssinaDigitalservice->createSignatureCertsing();

            $response->addDataSet(new DataSet("RESULT", $create));

        } catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    
    public function callbackCertsing(Request $request, Response $response){
        try {
            $parametros = $request->getParameters();
            $nrorg = $this->httpKernel->getHttpRequest()->getHeaders()->get("nrorg");

            $dadosIntegracao = $parametros["dataset"][0];
            
            $this->smAssinaDigitalservice->callbackCertsing($dadosIntegracao, $nrorg);

        } catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    
    public function incluirSignatario(Request $request, Response $response){
        try {
            
            $this->smAssinaDigitalservice->incluirSignatario($request);

        } catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    
    public function excluirSignatario(Request $request, Response $response){
        try {
            
            $this->smAssinaDigitalservice->excluirSignatario($request);

        } catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    
    public function reenviarSolicitacao(Request $request, Response $response){
        try {
            
            $this->smAssinaDigitalservice->reenviarSolicitacao($request);

        } catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    
    public function excluirdocumento(Request $request, Response $response){
        try {
            $this->smAssinaDigitalservice->excluirdocumento($request);

        } catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
}