<?php
namespace Teknisa\SM\Service;

use Teknisa\Libs\Util\NewCode;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\Utilities;

class ConfirmaEnderecoService {
    
    protected $confirmaEnderecoFactory;
    protected $environment;
    protected $newCode;
    
    public function __construct($confirmaEnderecoFactory, Environment $environment, NewCode $newCode){
        $this->confirmaEnderecoFactory = $confirmaEnderecoFactory;
        $this->environment             = $environment;
        $this->newCode                 = $newCode;
    }
    
    public function confirmAddress($address){
        
        $messages       = '';
        $pais           = !empty($address['NMPAIS']) ? $address['NMPAIS'] : null;
        $cdpais         = $address['CDPAIS'];
        $paisSemAcento  = Utilities::removeAccents($pais);

        $dataParamsPais = array(
            "NMPAIS"            => $pais,
            "PAISSEMACENTO"     => $paisSemAcento
        );

        $paisConfirmado = $this->confirmaEnderecoFactory->searchCountry($dataParamsPais);
        $address['NMPAIS']      = $paisConfirmado ? $paisConfirmado : '';
        
        if(!empty($paisConfirmado)){
            $estado           = !empty($address['NMESTADO']) ? $address['NMESTADO'] : null;
            $sgestado         = !empty($address['SGESTADO']) ? $address['SGESTADO'] : null;
            $estadoSemAcento  = Utilities::removeAccents($estado);
            
            $dataParamsEstado = array(
                "NMESTADO"              => $estado,
                "NMESTADOSEMACENTO"     => $estadoSemAcento,
                "CDPAIS"                => $cdpais
            );

            $estadoConfirmado = $this->confirmaEnderecoFactory->searchState($dataParamsEstado);
            $address['NMESTADO']    = $estadoConfirmado ? $estadoConfirmado : '';
        
            if(!empty($estadoConfirmado)){
                $municipio           = !empty($address['NMMUNICIPIO']) ? $address['NMMUNICIPIO'] : null;
                $cdmunicipio         = !empty($address['CDMUNICIPIO']) ? $address['CDMUNICIPIO'] : null;
                $municipioSemAcento  = Utilities::removeAccents($municipio);

                $dataParamsCidade = array(
                    "NMMUNICIPIO"           => $municipio, 
                    "NMMUNICIPIOSEMACENDO"  => $municipioSemAcento, 
                    "CDPAIS"                => $cdpais, 
                    "SGESTADO"              => $sgestado   
                );

                $municipioConfirmado = $this->confirmaEnderecoFactory->searchCity($dataParamsCidade);
                $address['NMMUNICIPIO'] = $municipioConfirmado ? $municipioConfirmado : '';
                
                 if(!empty($municipioConfirmado)){
                    $bairro           = !empty($address['NMBAIRRO']) ? $address['NMBAIRRO'] : null;
                    if(!is_null($bairro)){
                        $bairroSemAcento  = Utilities::removeAccents($bairro);
                        
                        $dataParamsBairro = array(
                            "NMBAIRRO"          => $bairro, 
                            "NMBAIRROSEMACENTO" => $bairroSemAcento, 
                            "CDPAIS"            => $cdpais, 
                            "SGESTADO"          => $sgestado, 
                            "CDMUNICIPIO"       => $cdmunicipio
                        );

                        $bairroConfirmado = $this->confirmaEnderecoFactory->searchNeigh($dataParamsBairro);
                        
                        if(!empty($bairroConfirmado)){
                            $address['CDBAIRRO'] = $bairroConfirmado['CDBAIRRO'];
                        }
                        /*else {
                            $nrorg = $this->environment->getNrOrg();
                            $cdoperador = $this->environment->getCdOperador();
                            
                            $idNovoCodigo = "BAIRRO" . $address["CDPAIS"] . $address["SGESTADO"] . $address["CDMUNICIPIO"];
                            $cdbairro = $this->newCode->getCodeByTableName("$idNovoCodigo", $nrorg);
                            
                            $params = array(
                                "CDPAIS"         => $address["CDPAIS"],
                                "SGESTADO"       => $address["SGESTADO"],
                                "CDMUNICIPIO"    => $address["CDMUNICIPIO"],
                                "CDBAIRRO"       => $cdbairro,
                                "NMBAIRRO"       => $address["NMBAIRRO"],
                                "IDATIVO"        => "S",
                                "NRORG"          => $nrorg,
                                "CDOPERINCLUSAO" => $cdoperador,
                                "NRORGINCLUSAO"  => $nrorg
                            );
                            $this->confirmaEnderecoFactory->inserirBairro($params);
                            
                            $address['CDBAIRRO'] = $cdbairro;
                            //$messages = 'Bairro não encontrado, favor inserir manualmente.';
                        }*/
                    }else{
                        $messages = 'Busca do CEP não retornou o nome do bairro. Caso necessário, favor inserir manualmente.';
                    }
                }else{
                    $messages = 'Município e Bairro não encontrados, favor inserir manualmente.';
                }
            }else{
                $messages = 'Estado não encontrado, favor inserir manualmente.';
            }
        }else{
            $messages = 'País não encontrado, favor inserir manualmente.';
        }
        
        return array('ADDRESS' => $address, 'MESSAGES' => $messages);
        
    }

}